Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(496)

Unified Diff: lib/html/src/_Lists.dart

Issue 11275042: Renaming IndexOutOfRangeException to RangeError. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Regenerated html files. Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/html/dartium/html_dartium.dart ('k') | lib/io/file_impl.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/html/src/_Lists.dart
diff --git a/lib/html/src/_Lists.dart b/lib/html/src/_Lists.dart
index 712600c0aa2bb8091775500eb42bcacceafd4f66..75d79055ed7c415ffb9cd6d2178e2f082c8bcb62 100644
--- a/lib/html/src/_Lists.dart
+++ b/lib/html/src/_Lists.dart
@@ -52,14 +52,13 @@ class _Lists {
* [:start + length:].
* Returns an empty list if [length] is 0.
* Throws an [ArgumentError] if [length] is negative.
* Throws an [IndexOutOfRangeException] if [start] or
* [:start + length:] are out of range.
*/
static List getRange(List a, int start, int length, List accumulator) {
if (length < 0) throw new ArgumentError('length');
- if (start < 0) throw new IndexOutOfRangeException(start);
+ if (start < 0) throw new RangeError.value(start);
int end = start + length;
- if (end > a.length) throw new IndexOutOfRangeException(end);
+ if (end > a.length) throw new RangeError.value(end);
for (int i = start; i < end; i++) {
accumulator.add(a[i]);
}
@@ -52,14 +52,13 @@ class _Lists {
* Returns an empty list if [length] is 0.
* Throws an [ArgumentError] if [length] is negative.
- * Throws an [IndexOutOfRangeException] if [start] or
- * [:start + length:] are out of range.
+ * Throws a [RangeError] if [start] or [:start + length:] are out of range.
*/
static List getRange(List a, int start, int length, List accumulator) {
« no previous file with comments | « lib/html/dartium/html_dartium.dart ('k') | lib/io/file_impl.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698